Slurmize
========

Little app to generate `Slurm <https://slurm.schedmd.com/>`
*batch scripts*.

This package provides ``slurmize``: a TUI (Terminal User Interface)
program based on `Textual <https://textual.textualize.io/>` that guides
you in the process of creating and managing *batch scripts*. 

.. warning::

   Slurmize is **work In Progress!**
